Skip to contents

Assemble download data from selected genera

Usage

assemble_download_data(
  selected_list,
  shared_reactives,
  group_defs,
  taxonomy_data
)

Arguments

selected_list

Named list. Each element corresponds to a section and must have a $data field that is a list of row lists.

shared_reactives

List-like object with user_title and user_date.

group_defs

Data frame with columns section_id, group_id, group_name.

Value

A data.frame or NULL if there are no rows.