Skip to contents

Appends a final "IBI Score (0-50)" row whose adj_score is the sum of all other adjusted scores. Thin wrapper around summarize_metric_scores().

Usage

build_summarized_metrics(metric_scores_data)

Arguments

metric_scores_data

A data.frame with at least an adj_score column.

Value

A data.frame with the original rows plus a final IBI summary row.