Skip to contents

Given a tree layout (as returned by layout_tree()), draw a taxonomic tree using base R graphics. This is used by the Shiny module for on-screen rendering and PNG downloads.

Usage

draw_tree_base(tree, axis_levels = rank_levels)

Arguments

tree

A list with elements nodes, edges, coords, and leaf_tsns, as returned by layout_tree().

axis_levels

Character vector of rank labels to show on the x axis.

Value

Invisibly returns NULL after plotting.