Looks for pdflatex or xelatex on the system PATH, and
falls back to checking for a TinyTeX installation via the tinytex
package (listed in Suggests).
Looks for pdflatex or xelatex on the system PATH, and
falls back to checking for a TinyTeX installation via the tinytex
package (listed in Suggests).