These packages are used inside the R Markdown templates in inst/. This block exists so R CMD check sees that the Imports are actually used.
These packages are used inside the R Markdown templates in inst/. This block exists so R CMD check sees that the Imports are actually used.