Given the taxonomy, group list, and a selected taxon name, return a list with taxon, section_id, tsn, and parentTsn. If the taxon is missing or ambiguous, returns NULLs.
Given the taxonomy, group list, and a selected taxon name, return a list with taxon, section_id, tsn, and parentTsn. If the taxon is missing or ambiguous, returns NULLs.