This function initializes package paths, loads bundled data, and returns the MacroIBI Shiny application object.
Value
A shiny.appobj that can be passed to shiny::runApp().
Examples
if (interactive()) {
run_macroibi()
}
This function initializes package paths, loads bundled data, and returns the MacroIBI Shiny application object.
A shiny.appobj that can be passed to shiny::runApp().
if (interactive()) {
run_macroibi()
}